# encoding: utf-8
# Code generated by Microsoft (R) AutoRest Code Generator.
# Changes may cause incorrect behavior and will be lost if the code is
# regenerated.

module Azure::Support::Mgmt::V2020_04_01
  #
  # Microsoft Azure Support Resource Provider.
  #
  class ProblemClassifications
    include MsRestAzure

    #
    # Creates and initializes a new instance of the ProblemClassifications class.
    # @param client service class for accessing basic functionality.
    #
    def initialize(client)
      @client = client
    end

    # @return [MicrosoftSupport] reference to the MicrosoftSupport
    attr_reader :client

    #
    # Lists all the problem classifications (categories) available for a specific
    # Azure service. Always use the service and problem classifications obtained
    # programmatically. This practice ensures that you always have the most recent
    # set of service and problem classification Ids.
    #
    # @param service_name [String] Name of the Azure service for which the problem
    # classifications need to be retrieved.
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [ProblemClassificationsListResult] operation results.
    #
    def list(service_name, custom_headers:nil)
      response = list_async(service_name, custom_headers:custom_headers).value!
      response.body unless response.nil?
    end

    #
    # Lists all the problem classifications (categories) available for a specific
    # Azure service. Always use the service and problem classifications obtained
    # programmatically. This practice ensures that you always have the most recent
    # set of service and problem classification Ids.
    #
    # @param service_name [String] Name of the Azure service for which the problem
    # classifications need to be retrieved.
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [MsRestAzure::AzureOperationResponse] HTTP response information.
    #
    def list_with_http_info(service_name, custom_headers:nil)
      list_async(service_name, custom_headers:custom_headers).value!
    end

    #
    # Lists all the problem classifications (categories) available for a specific
    # Azure service. Always use the service and problem classifications obtained
    # programmatically. This practice ensures that you always have the most recent
    # set of service and problem classification Ids.
    #
    # @param service_name [String] Name of the Azure service for which the problem
    # classifications need to be retrieved.
    # @param [Hash{String => String}] A hash of custom headers that will be added
    # to the HTTP request.
    #
    # @return [Concurrent::Promise] Promise object which holds the HTTP response.
    #
    def list_async(service_name, custom_headers:nil)
      fail ArgumentError, 'service_name is nil' if service_name.nil?
      fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


      request_headers = {}
      request_headers['Content-Type'] = 'application/json; charset=utf-8'

      # Set Headers
      request_headers['x-ms-client-request-id'] = SecureRandom.uuid
      request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
      path_template = 'providers/Microsoft.Support/services/{serviceName}/problemClassifications'

      request_url = @base_url || @client.base_url

      options = {
          middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
          path_params: {'serviceName' => service_name},
          query_params: {'api-version' => @client.api_version},
          headers: request_headers.merge(custom_headers || {}),
          base_url: request_url
      }
      promise = @client.make_request_async(:get, path_template, options)

      promise = promise.then do |result|
        http_response = result.response
        status_code = http_response.status
        response_content = http_response.body
        unless status_code == 200
          error_model = JSON.load(response_content)
          fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
        end

        result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
        result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
        result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
        # Deserialize Response
        if status_code == 200
          begin
            parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
            result_mapper = Azure::Support::Mgmt::V2020_04_01::Models::ProblemClassificationsListResult.mapper()
            result.body = @client.deserialize(result_mapper, parsed_response)
          rescue Exception => e
            fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
          end
        end

        result
      end

      promise.execute
    end

    #
    # Get problem classification details for a specific Azure service.
    #
    # @param service_name [String] Name of the Azure service available for support.
    # @param problem_classification_name [String] Name of problem classification.
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [ProblemClassification] operation results.
    #
    def get(service_name, problem_classification_name, custom_headers:nil)
      response = get_async(service_name, problem_classification_name, custom_headers:custom_headers).value!
      response.body unless response.nil?
    end

    #
    # Get problem classification details for a specific Azure service.
    #
    # @param service_name [String] Name of the Azure service available for support.
    # @param problem_classification_name [String] Name of problem classification.
    # @param custom_headers [Hash{String => String}] A hash of custom headers that
    # will be added to the HTTP request.
    #
    # @return [MsRestAzure::AzureOperationResponse] HTTP response information.
    #
    def get_with_http_info(service_name, problem_classification_name, custom_headers:nil)
      get_async(service_name, problem_classification_name, custom_headers:custom_headers).value!
    end

    #
    # Get problem classification details for a specific Azure service.
    #
    # @param service_name [String] Name of the Azure service available for support.
    # @param problem_classification_name [String] Name of problem classification.
    # @param [Hash{String => String}] A hash of custom headers that will be added
    # to the HTTP request.
    #
    # @return [Concurrent::Promise] Promise object which holds the HTTP response.
    #
    def get_async(service_name, problem_classification_name, custom_headers:nil)
      fail ArgumentError, 'service_name is nil' if service_name.nil?
      fail ArgumentError, 'problem_classification_name is nil' if problem_classification_name.nil?
      fail ArgumentError, '@client.api_version is nil' if @client.api_version.nil?


      request_headers = {}
      request_headers['Content-Type'] = 'application/json; charset=utf-8'

      # Set Headers
      request_headers['x-ms-client-request-id'] = SecureRandom.uuid
      request_headers['accept-language'] = @client.accept_language unless @client.accept_language.nil?
      path_template = 'providers/Microsoft.Support/services/{serviceName}/problemClassifications/{problemClassificationName}'

      request_url = @base_url || @client.base_url

      options = {
          middlewares: [[MsRest::RetryPolicyMiddleware, times: 3, retry: 0.02], [:cookie_jar]],
          path_params: {'serviceName' => service_name,'problemClassificationName' => problem_classification_name},
          query_params: {'api-version' => @client.api_version},
          headers: request_headers.merge(custom_headers || {}),
          base_url: request_url
      }
      promise = @client.make_request_async(:get, path_template, options)

      promise = promise.then do |result|
        http_response = result.response
        status_code = http_response.status
        response_content = http_response.body
        unless status_code == 200
          error_model = JSON.load(response_content)
          fail MsRest::HttpOperationError.new(result.request, http_response, error_model)
        end

        result.request_id = http_response['x-ms-request-id'] unless http_response['x-ms-request-id'].nil?
        result.correlation_request_id = http_response['x-ms-correlation-request-id'] unless http_response['x-ms-correlation-request-id'].nil?
        result.client_request_id = http_response['x-ms-client-request-id'] unless http_response['x-ms-client-request-id'].nil?
        # Deserialize Response
        if status_code == 200
          begin
            parsed_response = response_content.to_s.empty? ? nil : JSON.load(response_content)
            result_mapper = Azure::Support::Mgmt::V2020_04_01::Models::ProblemClassification.mapper()
            result.body = @client.deserialize(result_mapper, parsed_response)
          rescue Exception => e
            fail MsRest::DeserializationError.new('Error occurred in deserializing the response', e.message, e.backtrace, result)
          end
        end

        result
      end

      promise.execute
    end

  end
end
